@@ -625,7 +625,7 @@ class MDSimulation():
         os.remove('temp_pdb.pdb')
 
         # write the h5 file
-        print('saving minimized coordinates to {}'.format(os.path.join(self.cwd, fname)))
+        print('saving current coordinates to {}'.format(os.path.join(self.cwd, fname)))
         frame.save_hdf5(os.path.join(self.cwd, fname))
 
     def pickle_sim(self, pickle_name='mdsim.pickle'):
