@@ -5,6 +5,8 @@ import re
 
 import mdtraj
 import numpy as np
+from scipy.spatial import distance
+
 from simtk.openmm import unit
 
 from .ommtk import MetadynamicSimulation
@@ -38,7 +40,7 @@ class SegmentMappingSim(MetadynamicSimulation):
                  scan_time = 1 * unit.nanosecond, scan_bias_freq= .5 * unit.picosecond,
                  max_scan_time=6 * unit.nanosecond, prod_bias=5, prod_bias_freq = 1 * unit.picosecond,
                  scan_bias_height=2.5 * unit.kilojoules_per_mole, prod_bias_height= 2 * unit.kilojoule_per_mole,
-                 num_replicas=1,
+                 num_replicas=1, CV2_target_range = None,
                  total_production_time = 100 * unit.nanosecond, **kwargs):
 
         super().__init__(**kwargs)
@@ -58,6 +60,10 @@ class SegmentMappingSim(MetadynamicSimulation):
         self.total_production_time = total_production_time
         self.prod_bias_height = prod_bias_height
 
+
+        self.CV2_target_range = CV2_target_range
+
+
         for cv in self.CV_list:
             if cv[0]=='Distance' and cv[4]<self.unbound_distance:
                 self.unbound_distance=cv[4]
@@ -116,11 +122,8 @@ class SegmentMappingSim(MetadynamicSimulation):
 
             distances = np.array(CVs)[:, 0]
 
-            print('CV distances {}'.format(distances))
-
             scan_clock = self.scan_time
             while all(distances < distances[0]+self.unbound_distance) and  scan_clock<self.max_scan_time:
-                print('UNBOUND DISTANCE', self.unbound_distance)
 
                 print('failed to unbind, scanning for another .5 ns')
                 print('CV distance range {} to {}'.format(distances[0],np.max(distances)))
@@ -145,22 +148,35 @@ class SegmentMappingSim(MetadynamicSimulation):
 
             self.simulation.reporters.clear()
 
-            #find traj frames where the CV is evenly spaced along num_seg segments
-            segment_targets = np.linspace(np.min(distances), self.unbound_distance, self.num_segs)
+            # find traj frames where the CV is evenly spaced along num_seg segments in distance CV but
+            # but optionally constrain CV2 values to a uniform distribution within a specified range
+            distance_targets = np.linspace(np.min(distances), self.unbound_distance, self.num_segs)
+            if self.CV2_target_range:
+                #make sure min and max aren't outside the CV range
+                min = np.max([self.CV_list[1][3],CVs[0][1]-self.CV2_target_range])
+                max = np.min([CVs[0][1]+self.CV2_target_range,self.CV_list[1][4]])
+                CV2_targets = np.random.uniform(min,max,self.num_segs)
+                print('CV2_targets',CV2_targets)
 
             segment_frames = []
             chosen_CVs = []
-            for target in segment_targets:
-                idx = (np.abs(distances - target)).argmin()
+            for k,target in enumerate(distance_targets):
+                if self.CV2_target_range:
+                    idx = np.argmin(distance.cdist([(target, CV2_targets[k])], CVs))
+                else:
+                    idx = (np.abs(distances - target)).argmin()
                 #if idx is already in the list, try 100 times to choose another with similar value
                 counter=0
                 while idx in segment_frames and counter<100:
                     counter+=1
                     target+=random.randint(-100,100)* .01
-                    idx = (np.abs(distances - target)).argmin()
+                    if self.CV2_target_range:
+                        idx = np.argmin(distance.cdist([(target, CV2_targets[k])], CVs))
+                    else:
+                        idx = (np.abs(distances - target)).argmin()
                 segment_frames.append(idx)
                 chosen_CVs.append(distances[idx])
-                print('choosing CV value {} {}'.format(idx,distances[idx]))
+                print('choosing CV values {} {}'.format(idx,CVs[idx]))
 
             #load trajectory and slice for chosen frames
             traj = mdtraj.load_hdf5(os.path.join(self.cwd,self.traj_out))
