@@ -5,7 +5,7 @@ from simtk.openmm import unit
 
 
 aa_residues = ["ALA", "CYS", "ASP", "GLU", "PHE", "GLY", "HIS", "ILE", "LYS",
-               "LEU", "MET", "ASN", "PRO", "GLN", "ARG", "SER", "THR", "VAL", "TRP", "TYR"]
+               "LEU", "MET", "ASN", "PRO", "GLN", "ARG", "SER", "THR", "VAL", "TRP", "TYR", "ACE", "NME"]
 
 water_residues = ['HOH', 'TIP3', 'TIP3P', 'SPCE', 'SPC', 'TIP4PEW', 'WAT', 'OH2', 'TIP']
 
